@@ -12,7 +12,7 @@ Usage::
     session_client: RDSDataServiceClient = session.client("rds-data")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, List, TYPE_CHECKING
+from typing import Any, Dict, List, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_rds_data.type_defs import (
     BatchExecuteStatementResponseTypeDef,
@@ -30,18 +30,18 @@ __all__ = ("RDSDataServiceClient",)
 
 
 class Exceptions:
-    BadRequestException: Boto3ClientError
-    ClientError: Boto3ClientError
-    ForbiddenException: Boto3ClientError
-    InternalServerErrorException: Boto3ClientError
-    NotFoundException: Boto3ClientError
-    ServiceUnavailableError: Boto3ClientError
-    StatementTimeoutException: Boto3ClientError
+    BadRequestException: Type[Boto3ClientError]
+    ClientError: Type[Boto3ClientError]
+    ForbiddenException: Type[Boto3ClientError]
+    InternalServerErrorException: Type[Boto3ClientError]
+    NotFoundException: Type[Boto3ClientError]
+    ServiceUnavailableError: Type[Boto3ClientError]
+    StatementTimeoutException: Type[Boto3ClientError]
 
 
 class RDSDataServiceClient:
     """
-    [RDSDataService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/rds-data.html#RDSDataService.Client)
+    [RDSDataService.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/rds-data.html#RDSDataService.Client)
     """
 
     exceptions: Exceptions
@@ -57,26 +57,26 @@ class RDSDataServiceClient:
         transactionId: str = None,
     ) -> BatchExecuteStatementResponseTypeDef:
         """
-        [Client.batch_execute_statement documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
+        [Client.batch_execute_statement documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/rds-data.html#RDSDataService.Client.batch_execute_statement)
         """
 
     def begin_transaction(
         self, resourceArn: str, secretArn: str, database: str = None, schema: str = None
     ) -> BeginTransactionResponseTypeDef:
         """
-        [Client.begin_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
+        [Client.begin_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/rds-data.html#RDSDataService.Client.begin_transaction)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/rds-data.html#RDSDataService.Client.can_paginate)
         """
 
     def commit_transaction(
         self, resourceArn: str, secretArn: str, transactionId: str
     ) -> CommitTransactionResponseTypeDef:
         """
-        [Client.commit_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
+        [Client.commit_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/rds-data.html#RDSDataService.Client.commit_transaction)
         """
 
     def execute_sql(
@@ -88,7 +88,7 @@ class RDSDataServiceClient:
         schema: str = None,
     ) -> ExecuteSqlResponseTypeDef:
         """
-        [Client.execute_sql documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
+        [Client.execute_sql documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/rds-data.html#RDSDataService.Client.execute_sql)
         """
 
     def execute_statement(
@@ -105,7 +105,7 @@ class RDSDataServiceClient:
         transactionId: str = None,
     ) -> ExecuteStatementResponseTypeDef:
         """
-        [Client.execute_statement documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
+        [Client.execute_statement documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/rds-data.html#RDSDataService.Client.execute_statement)
         """
 
     def generate_presigned_url(
@@ -116,12 +116,12 @@ class RDSDataServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/rds-data.html#RDSDataService.Client.generate_presigned_url)
         """
 
     def rollback_transaction(
         self, resourceArn: str, secretArn: str, transactionId: str
     ) -> RollbackTransactionResponseTypeDef:
         """
-        [Client.rollback_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.28/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
+        [Client.rollback_transaction documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.29/reference/services/rds-data.html#RDSDataService.Client.rollback_transaction)
         """
